@@ -1,8 +1,6 @@
 package dumper
 
 import (
-	"regexp"
-
 	"github.com/skeema/skeema/internal/tengo"
 )
 
@@ -11,7 +9,6 @@ type Options struct {
 	IncludeAutoInc bool                     // if false, strip AUTO_INCREMENT clauses from CREATE TABLE
 	Partitioning   tengo.PartitioningMode   // PartitioningKeep: retain previous FS partitioning clause; PartitioningRemove: strip partitioning clause
 	CountOnly      bool                     // if true, skip writing files, just report count of rewrites
-	IgnoreTable    *regexp.Regexp           // skip tables with names matching this regex
 	skipKeys       map[tengo.ObjectKey]bool // skip objects with true values
 	onlyKeys       map[tengo.ObjectKey]bool // if map is non-nil, only format objects with true values
 }
@@ -48,9 +45,6 @@ func (opts *Options) shouldIgnore(keyer tengo.ObjectKeyer) bool {
 	if opts.skipKeys[key] {
 		return true
 	}
-	if key.Type == tengo.ObjectTypeTable && opts.IgnoreTable != nil && opts.IgnoreTable.MatchString(key.Name) {
-		return true
-	}
 	if opts.onlyKeys != nil && !opts.onlyKeys[key] {
 		return true
 	}
