@@ -40,7 +40,7 @@ var reDefinerCheckerOffset = regexp.MustCompile("(?i)definer")
 var repDefinerQuotes = strings.NewReplacer("'", "", "`", "")
 var repDefinerWildcards = strings.NewReplacer("%", ".*", "_", ".")
 
-func definerChecker(object tengo.DefKeyer, createStatement string, schema *tengo.Schema, opts Options) []Note {
+func definerChecker(object tengo.DefKeyer, createStatement string, schema *tengo.Schema, opts *Options) []Note {
 	dc := opts.RuleConfig["definer"].(*definerConfig)
 
 	// Performance hack for default settings case
@@ -50,7 +50,7 @@ func definerChecker(object tengo.DefKeyer, createStatement string, schema *tengo
 
 	var typ, name, definer string
 	if object, ok := object.(*tengo.Routine); ok {
-		typ, name, definer = strings.Title(string(object.Type)), object.Name, object.Definer
+		typ, name, definer = strings.Title(string(object.Type)), tengo.EscapeIdentifier(object.Name), object.Definer
 	} else {
 		return nil
 	}
