@@ -18,7 +18,7 @@ func init() {
 
 var reHasFK = regexp.MustCompile(`(?i)foreign key`)
 
-func hasForeignKeysChecker(table *tengo.Table, createStatement string, _ *tengo.Schema, _ Options) *Note {
+func hasForeignKeysChecker(table *tengo.Table, createStatement string, _ *tengo.Schema, _ *Options) *Note {
 	if len(table.ForeignKeys) == 0 {
 		return nil
 	}
@@ -28,7 +28,7 @@ func hasForeignKeysChecker(table *tengo.Table, createStatement string, _ *tengo.
 	}
 	message := fmt.Sprintf(
 		"Table %s has %d foreign key%s. Foreign keys may harm write performance, and can be problematic for online schema change tools. They are also ineffective in sharded environments.",
-		table.Name, len(table.ForeignKeys), plural,
+		tengo.EscapeIdentifier(table.Name), len(table.ForeignKeys), plural,
 	)
 	return &Note{
 		LineOffset: FindFirstLineOffset(reHasFK, createStatement),
