@@ -1,7 +1,7 @@
 package linter
 
 import (
-	"fmt"
+	"strings"
 
 	"github.com/skeema/skeema/internal/tengo"
 )
@@ -15,9 +15,11 @@ func init() {
 	})
 }
 
-func hasRoutinesChecker(routine *tengo.Routine, _ string, _ *tengo.Schema, _ Options) *Note {
+func hasRoutinesChecker(routine *tengo.Routine, _ string, _ *tengo.Schema, _ *Options) *Note {
+	keyString := routine.ObjectKey().String()
+	noun := strings.ToUpper(keyString[0:1]) + keyString[1:]
 	return &Note{
 		Summary: "Routine present",
-		Message: fmt.Sprintf("%s %s found. Some environments restrict use of stored procedures and functions for reasons of scalability or operational complexity.", routine.Type, routine.Name),
+		Message: noun + " found. Some environments restrict use of stored procedures and functions for reasons of scalability or operational complexity.",
 	}
 }
