@@ -18,7 +18,7 @@ func init() {
 	})
 }
 
-func idsChecker(table *tengo.Table, createStatement string, _ *tengo.Schema, _ Options) []Note {
+func idsChecker(table *tengo.Table, createStatement string, _ *tengo.Schema, _ *Options) []Note {
 	results := make([]Note, 0)
 	for _, col := range table.Columns {
 		lowerColName := strings.ToLower(col.Name)
@@ -33,8 +33,8 @@ func idsChecker(table *tengo.Table, createStatement string, _ *tengo.Schema, _ O
 		}
 
 		message := fmt.Sprintf(
-			"Column %s of table %s is using data type %s. If this column is intended to store an integer ID, please use data type bigint unsigned instead.",
-			col.Name, table.Name, col.TypeInDB,
+			"Column %s of %s is using data type %s. If this column is intended to store an integer ID, please use data type bigint unsigned instead.",
+			col.Name, table.ObjectKey(), col.TypeInDB,
 		)
 		results = append(results, Note{
 			LineOffset: FindColumnLineOffset(col, createStatement),
