@@ -540,14 +540,17 @@ func processCreateTable(p *parser, tokens []Token) (*Statement, error) {
 		p.stmt.ObjectType = ObjectTypeTable
 	}
 
-	matched, tokens := p.skipUntilSequence(tokens, "select")
+	// A different StatementType is used in these cases:
+	// * CREATE...SELECT: not supported since it mixes DDL with DML, isn't allowed
+	//   on database servers using GTID in MySQL 5.6-8.0.20, causes problems with
+	//   Skeema's workspace operation model, and presents potential security
+	//   problems in multi-tenant environments running Skeema with elevated grants
+	// * MariaDB system-versioned tables: these use a nonstandard value in
+	//   information_schema.tables.table_type, and Skeema does not yet introspect
+	//   them, causing `skeema pull` to delete their filesystem definition
+	matched, tokens := p.skipUntilSequence(tokens, "select", "with system versioning")
 	if matched != nil {
-		p.err = &MalformedSQLError{
-			str:        "Statements of the form CREATE TABLE...SELECT are not supported",
-			filePath:   p.filePath,
-			lineNumber: p.lineNumber,
-			colNumber:  p.colNumber,
-		}
+		p.stmt.Type = StatementTypeCreateUnsupported
 	}
 
 	return processUntilDelimiter(p, tokens)
