@@ -2,6 +2,7 @@ package main
 
 import (
 	"fmt"
+	"io"
 	"os"
 	"runtime"
 	"strings"
@@ -472,22 +473,19 @@ func (s SkeemaIntegrationSuite) TestDiffHandler(t *testing.T) {
 		// --brief manipulates the log level, so we must restore it after
 		log.SetLevel(log.DebugLevel)
 	}()
+	r, w, err := os.Pipe()
+	if err != nil {
+		t.Fatalf("Unable to redirect stdout to a pipe: %v", err)
+	}
 	oldStdout := os.Stdout
-	if outFile, err := os.Create("diff-brief.out"); err != nil {
-		t.Fatalf("Unable to redirect stdout to a file: %s", err)
-	} else {
-		os.Stdout = outFile
-		s.handleCommand(t, CodeDifferencesFound, ".", "skeema diff --brief")
-		outFile.Close()
-		os.Stdout = oldStdout
-		expectOut := fmt.Sprintf("%s\n", s.d.Instance)
-		actualOut := fs.ReadTestFile(t, "diff-brief.out")
-		if actualOut != expectOut {
-			t.Errorf("Unexpected output from `skeema diff --brief`\nExpected:\n%sActual:\n%s", expectOut, actualOut)
-		}
-		if err := os.Remove("diff-brief.out"); err != nil {
-			t.Fatalf("Unable to delete diff-brief.out: %s", err)
-		}
+	os.Stdout = w
+	s.handleCommand(t, CodeDifferencesFound, ".", "skeema diff --brief")
+	w.Close()
+	os.Stdout = oldStdout
+	expectOut := s.d.Instance.String() + "\n"
+	actualOut, err := io.ReadAll(r)
+	if err != nil || string(actualOut) != expectOut {
+		t.Errorf("Unexpected output from `skeema diff --brief`. Expected: %q   Actual: %q", expectOut, string(actualOut))
 	}
 }
 
@@ -517,12 +515,13 @@ func (s SkeemaIntegrationSuite) TestPushHandler(t *testing.T) {
 	// changes (analytics) but not for schemas with 1 or more unsafe changes
 	// (product). It shouldn't not affect the `bonus` schema (which exists on db
 	// but not on filesystem, but push should never drop schemas)
-	s.handleCommand(t, CodeFatalError, "", "skeema push")            // CodeFatalError due to unsafe changes not being allowed
-	s.handleCommand(t, CodeSuccess, "mydb/analytics", "skeema diff") // analytics dir was pushed fine tho
-	s.assertTableExists(t, "analytics", "pageviews", "")             // re-created by push
-	s.assertTableMissing(t, "product", "users", "credits")           // product DDL skipped due to unsafe stmt
-	s.assertTableExists(t, "product", "posts", "featured")           // product DDL skipped due to unsafe stmt
-	s.assertTableExists(t, "bonus", "placeholder", "")               // not affected by push (never drops schemas)
+	s.handleCommand(t, CodeFatalError, "", "skeema push")                          // CodeFatalError due to unsafe changes not being allowed
+	s.handleCommand(t, CodeBadConfig, ".", "skeema push --safe-below-size=potato") // only triggers an error when there are ALTERs present
+	s.handleCommand(t, CodeSuccess, "mydb/analytics", "skeema diff")               // analytics dir was pushed fine tho
+	s.assertTableExists(t, "analytics", "pageviews", "")                           // re-created by push
+	s.assertTableMissing(t, "product", "users", "credits")                         // product DDL skipped due to unsafe stmt
+	s.assertTableExists(t, "product", "posts", "featured")                         // product DDL skipped due to unsafe stmt
+	s.assertTableExists(t, "bonus", "placeholder", "")                             // not affected by push (never drops schemas)
 
 	// The "skip whole schema upon unsafe stmt" rule also affects schema-level DDL
 	if product, err := s.d.Schema("product"); err != nil || product == nil {
@@ -1470,7 +1469,8 @@ func (s SkeemaIntegrationSuite) TestTempSchemaBinlog(t *testing.T) {
 		Name:         strings.Replace(s.d.ContainerName(), "skeema-test-", "skeema-test-binlog-", 1),
 		Image:        s.d.Flavor().Family().String(),
 		RootPassword: s.d.Password,
-		CommandArgs:  []string{"--log-bin", "--server-id=1"},
+		EnableBinlog: true,
+		DataTmpfs:    true, // since we destroy the container after this test anyway
 	}
 	dinst, err := tengo.GetOrCreateDockerizedInstance(opts)
 	if err != nil {
